# Microservice Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines#definition)
  * [Modeling Microservices](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines#modeling-microservices)
  * [Antipattern](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines#antipattern)


This page covers modeling guidelines for microservices. Learn best practices for tracking their provisioning and dependencies effectively and avoid common antipatterns.
